import React from 'react';

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function JsonFormatter(_ref) {
  var json = _ref.json,
      _ref$tabWith = _ref.tabWith,
      tabWith = _ref$tabWith === void 0 ? 2 : _ref$tabWith,
      _ref$jsonStyle = _ref.jsonStyle,
      jsonStyle = _ref$jsonStyle === void 0 ? {} : _ref$jsonStyle;
  var jsonObject = JSON.parse(json);

  var repeatTabSpace = function repeatTabSpace(times) {
    var repeatedTabSpace = [];

    for (var i = 0; i < times; i++) {
      repeatedTabSpace.push(React.createElement("span", {
        key: i,
        style: jsonStyle.tabSpaceStyle
      }, '\xa0'.repeat(tabWith || 4)));
    }

    return repeatedTabSpace;
  };

  var TabSpaceRepeatTimes = 0;

  function categorize(data) {
    switch (Object.prototype.toString.call(data)) {
      case '[object Number]':
        {
          var dataJSX = React.createElement("span", {
            style: jsonStyle.numberStyle
          }, data);
          return dataJSX;
        }

      case '[object String]':
        {
          var _dataJSX = React.createElement("span", {
            style: jsonStyle.stringStyle
          }, "\"" + data + "\"");

          return _dataJSX;
        }

      case '[object Boolean]':
        {
          var _dataJSX2 = data ? React.createElement("span", {
            style: _extends({}, jsonStyle.booleanStyle, jsonStyle.trueStyle)
          }, "true") : React.createElement("span", {
            style: _extends({}, jsonStyle.booleanStyle, jsonStyle.trueStyle)
          }, "false");

          return _dataJSX2;
        }

      case '[object Object]':
        {
          var _dataJSX3 = [];

          _dataJSX3.push(React.createElement(React.Fragment, {
            key: '{'
          }, React.createElement("span", {
            style: jsonStyle.braceStyle
          }, '{'), React.createElement("br", null)));

          var keys = Object.keys(data);
          TabSpaceRepeatTimes += 1;
          Object.keys(data).forEach(function (key, index) {
            _dataJSX3.push(React.createElement(React.Fragment, {
              key: index
            }, repeatTabSpace(TabSpaceRepeatTimes), React.createElement("span", {
              style: jsonStyle.propertyStyle
            }, "\"" + key + "\": "), categorize(data[key]), index !== keys.length - 1 && React.createElement("span", null, ","), React.createElement("br", null)));
          });
          TabSpaceRepeatTimes -= 1;

          _dataJSX3.push(React.createElement(React.Fragment, {
            key: '}'
          }, repeatTabSpace(TabSpaceRepeatTimes), React.createElement("span", {
            style: jsonStyle.braceStyle
          }, '}')));

          return _dataJSX3;
        }

      case '[object Array]':
        {
          var _dataJSX4 = [];

          _dataJSX4.push(React.createElement(React.Fragment, {
            key: '['
          }, React.createElement("span", {
            style: jsonStyle.bracketStyle
          }, "["), React.createElement("br", null)));

          TabSpaceRepeatTimes += 1;

          for (var i = 0; i < data.length; i++) {
            _dataJSX4.push(React.createElement(React.Fragment, {
              key: i
            }, repeatTabSpace(TabSpaceRepeatTimes), categorize(data[i]), i === data.length - 1 ? null : React.createElement("span", {
              style: jsonStyle.commaStyle
            }, ","), React.createElement("br", null)));
          }

          TabSpaceRepeatTimes -= 1;

          _dataJSX4.push(React.createElement(React.Fragment, {
            key: ']'
          }, repeatTabSpace(TabSpaceRepeatTimes), React.createElement("span", {
            style: jsonStyle.bracketStyle
          }, "]")));

          return _dataJSX4;
        }

      case '[object Null]':
        {
          var _dataJSX5 = React.createElement("span", {
            style: jsonStyle.nullStyle
          }, "null");

          return _dataJSX5;
        }

      default:
        return React.createElement("span", null, "type error");
    }
  }

  return React.createElement("div", {
    style: jsonStyle.style
  }, React.createElement("div", null, categorize(jsonObject)));
}

export { JsonFormatter };
//# sourceMappingURL=index.modern.js.map
